@@ -1,3 +1,4 @@
+import json
 import os
 import random
 import numpy as np
@@ -80,13 +81,50 @@ def createJobShopModel(job_shop):
     js = job_shop.get_instance()
     js.set_search_timeout(10.0)
     js.set_num_parallel_cores(1)
-    machine_1 = js.add_machine(1)
-    machine_1.add_time_window_availability(32, 54)
-    job_1 = js.add_job(1)
-    job_1.add_dependency(machine_1.get_id())
-    task_1 = job_1.add_task()
-    task_1.set_required_machine(machine_1.get_id())
-    task_1.set_duration(10)
+    machine = js.add_machine(1)
+    machine.add_time_window_availability(32, 54)
+    job_1 = js.add_job(0)
+    job_2 = js.add_job(1)
+    job_2.add_dependency(job_1.get_id())
+    task_1 = job_1.add_task(0)
+    task_1.set_required_machine(machine.get_id())
+    task_2 = job_2.add_task(1)
+    task_2.set_required_machine(machine.get_id())
+    task_1.set_duration(5)
+    task_2.set_duration(5)
+
+
+def createJobShopModelFromData(js):
+    path_res = "data/res.json"
+    path_task = "data/task.json"
+    with open(path_res, encoding='utf-8-sig') as json_file:
+        text = json_file.read()
+        res_data = json.loads(text)
+    with open(path_task, encoding='utf-8-sig') as json_file:
+        text = json_file.read()
+        task_data = json.loads(text)
+
+    scaling_factor = 10
+    res_list = res_data['res']
+    for res in res_list:
+        machine_id = res['id']
+        machine = js.add_machine(machine_id, 'machine_' + str(machine_id))
+        periods = res['periods']
+        for period in periods:
+            machine.add_time_window_availability(int(period['s'] * scaling_factor), int(period['e'] * scaling_factor))
+
+    task_list = task_data['tasks']
+    for task in task_list:
+        job_id = task['id']
+        job = js.add_job(job_id, 'job_' + str(job_id))
+        job_task = job.add_task(job_id)
+        required_machine = task['res'][0]
+        task_duration = int(task['dur'] * scaling_factor)
+        job_task.set_required_machine(required_machine)
+        job_task.set_duration(task_duration)
+        for dep in task['dep']:
+            if dep > -1:
+                job.add_dependency(dep)
 
 
 def createCPModel(model):
@@ -118,6 +156,63 @@ def createPythonFunctionTool(tool):
     return tool
 
 
+def verifyJobShop(js):
+    job_list = js.get_all_jobs()
+    machine_list = js.get_all_machines()
+    model_consistency = True
+    scaling_factor = 1
+
+    # Store of the tasks into a map, just for convinience
+    task_map = {}
+    for job in job_list:
+        jtask = job.get_task_list()[0]
+        task_map[jtask.get_id()] = jtask
+
+    # Check start/end times for task dependencies
+    for job in job_list:
+        # For each job, get the task and its start time
+        curr_task_start = (job.get_task_list()[0]).get_start_time()
+        dep_list = job.get_dependency_list()
+        for dep in dep_list:
+            # For each dependency, check if the dependency finishes befor this job starts
+            jtask = task_map[dep]
+            dep_end_time = jtask.get_start_time() + jtask.get_duration()
+            if curr_task_start < dep_end_time:
+                model_consistency = False
+                print('Error: current Job', job.get_id(), "starts at", curr_task_start / scaling_factor,
+                      "and depends on", dep, "finishing at", dep_end_time / scaling_factor)
+
+    # Check machine execution list
+    for machine in machine_list:
+        # For each machine, get its availabilities and its schedule
+        schedule = machine.get_schedule()
+        window_availability = machine.get_time_window_availabilities()
+        for scheduled_task in schedule:
+            task_id = scheduled_task[0]
+            task_start = scheduled_task[1]
+            task_end = scheduled_task[2]
+            # Check that tasks are scheduled on the required machines
+            if task_map[task_id].get_required_machine() != machine.get_id():
+                model_consistency = False
+                print('Error: task', task_id, "should be scheduled on", task_map[task_id].set_required_machine(),
+                      "and it is scheduled on", machine.get_id())
+            # Check that tasks start when the machine is available
+            found_window = False
+            for window in window_availability:
+                if task_start >= window[0] and task_end <= window[1]:
+                    found_window = True
+                    break
+            if not found_window:
+                model_consistency = False
+                print('Error: task', task_id, "scheduled at", task_start / scaling_factor, task_end / scaling_factor,
+                      "does not respect machine window availability for machine ", machine.get_id())
+
+    if model_consistency:
+        print("The schedule is a valid schedule")
+    else:
+        print("The schedule is an invalid schedule")
+
+
 def runConnection(optimizer):
     print("Connecting...")
     optimizer.connect()
@@ -151,11 +246,9 @@ def runConnection(optimizer):
     elif model == "j":
         js = BuildJobShopScheduler("job_shop")
         createJobShopModel(js)
+        #createJobShopModelFromData(js.get_instance())
         optimizer.run_optimizer_synch(js)
-        jobs = js.get_instance().get_all_jobs()
-        print(js.get_instance().get_model_status())
-        for job in jobs:
-            print(job)
+        verifyJobShop(js.get_instance())
         js.get_instance().print_solution()
     elif model == "s":
         scheduler = BuildEmployeesScheduler('test')
