@@ -328,7 +328,7 @@ class JobShopProblem(scheduling_problem.SchedulingProblem):
             this_job_idx = self._job_protobuf_mapping[job.get_id()]
             dep_list = job.get_dependency_list()
             for dep in dep_list:
-                if dep is self._job_protobuf_mapping:
+                if dep in self._job_protobuf_mapping:
                     prec_proto = js_model.precedences.add()
                     prec_proto.first_job_index = self._job_protobuf_mapping[dep]
                     prec_proto.second_job_index = this_job_idx
