@@ -1,5 +1,5 @@
 from parallelsdk.client import ParallelClient
-from parallelsdk.pllai_mp_toolbox.mp_toolbox import *
+from parallelsdk.mp_toolbox.mp_toolbox import *
 
 mip = MPModel('mip_example')
 
